/*
 * Copyright (C) $Date: 86/09/19 17:01:07 $
 * by $Author: badri $
 * University of Rochester,
 * Department of Electrical Engineering.
 *
 * CoNtEnTs   This file contains various definitions for tput.
 *
 * $Locker:  $
 * $Source: /u/users/badri/usr/src/local/tput/RCS/tput.h,v $
 * $Revision: 1.2 $
 *
 * History of this release:
 * $Log:	tput.h,v $
 * Revision 1.2  86/09/19  17:01:07  badri
 * Did some rearranging of things. Also incorporated error messages.
 * 
 * Revision 1.1  86/09/18  15:48:24  badri
 * Initial revision
 * 
 */
#include <sgtty.h>
#include <stdio.h>

#ifndef XTABS
#define XTABS 0006000
#endif  XTABS

#define LARGEBUF 1024
#define SMALLBUF   64

#define SYSTEM    666
#define FAILURE     1
#define SUCCESS     0
#define BADUSE     -1
#define BADTERM    -2
#define BADCAP     -3
/*
 * To add new capabilities, increment table size and define the
 * capability in the appropriate slot in the structure. Note that 
 * the capabilities are lexicographically ordered. This ordering
 * must be maintained for the binary search to work.
 * Format for entry is 
 * {"capability", "termcap_key"},
 */
#define TABLESIZE 310
struct {char *key, *value} table[TABLESIZE] = {
	{"acsc", "ac"},
	{"am", "am"},
	{"bel", "bl"},
	{"blink", "mb"},
	{"bold", "md"},
	{"bw", "bw"},
	{"cbt", "bt"},
	{"chts", "HC"},
	{"civis", "vi"},
	{"clear", "cl"},
	{"cmdch", "CC"},
	{"cnorm", "ve"},
	{"cols", "co"},
	{"cr", "cr"},
	{"csr", "cs"},
	{"cub", "LE"},
	{"cub1", "le"},
	{"cud", "DO"},
	{"cud1", "do"},
	{"cuf", "RI"},
	{"cuf1", "nd"},
	{"cup", "cm"},
	{"cuu", "UP"},
	{"cuu1", "up"},
	{"cvvis", "vs"},
	{"da", "da"},
	{"db", "db"},
	{"dch", "DC"},
	{"dch1", "dc"},
	{"dim", "mh"},
	{"dl", "DL"},
	{"dl1", "dl"},
	{"dsl", "ds"},
	{"ech", "ec"},
	{"ed", "cd"},
	{"el", "ce"},
	{"el1", "cb"},
	{"enacs", "eA"},
	{"eo", "eo"},
	{"eslok", "es"},
	{"ff", "ff"},
	{"flash", "vb"},
	{"fsl", "fs"},
	{"gn", "gn"},
	{"hc", "hc"},
	{"hd", "hd"},
	{"home", "ho"},
	{"hpa", "ch"},
	{"hs", "hs"},
	{"ht", "ta"},
	{"hts", "st"},
	{"hu", "hu"},
	{"hz", "hz"},
	{"ich", "IC"},
	{"ich1", "ic"},
	{"if", "if"},
	{"il", "AL"},
	{"il1", "al"},
	{"in", "in"},
	{"ind", "sf"},
	{"indn", "SF"},
	{"invis", "mk"},
	{"ip", "ip"},
	{"iprog", "iP"},
	{"is1", "i1"},
	{"is2", "is"},
	{"is3", "i3"},
	{"it", "it"},
	{"kBEG", "&9"},
	{"kCAN", "&0"},
	{"kCMD", "*1"},
	{"kCPY", "*2"},
	{"kCRT", "*3"},
	{"kDC", "*4"},
	{"kDL", "*5"},
	{"kEND", "*7"},
	{"kEOL", "*8"},
	{"kEXT", "*9"},
	{"kFND", "*0"},
	{"kHLP", "#1"},
	{"kHOM", "#2"},
	{"kIC", "#3"},
	{"kLFT", "#4"},
	{"kMOV", "%b"},
	{"kMSG", "%a"},
	{"kNXT", "%c"},
	{"kOPT", "%d"},
	{"kPRT", "%f"},
	{"kPRV", "%e"},
	{"kRDO", "%g"},
	{"kRES", "%j"},
	{"kRIT", "%i"},
	{"kRPL", "%h"},
	{"kSAV", "!1"},
	{"kSPD", "!2"},
	{"kUND", "!3"},
	{"ka1", "K1"},
	{"ka3", "K3"},
	{"kb2", "K2"},
	{"kbeg", "@1"},
	{"kbs", "kb"},
	{"kc1", "K4"},
	{"kc3", "K5"},
	{"kcan", "@2"},
	{"kcbt", "kB"},
	{"kclo", "@3"},
	{"kclr", "kC"},
	{"kcmd", "@4"},
	{"kcpy", "@5"},
	{"kcrt", "@6"},
	{"kctab", "kt"},
	{"kcub1", "kl"},
	{"kcud1", "kd"},
	{"kcuf1", "kr"},
	{"kcuu1", "ku"},
	{"kdch1", "kD"},
	{"kdl1", "kL"},
	{"ked", "kS"},
	{"kel", "kE"},
	{"kend", "@7"},
	{"kent", "@8"},
	{"kext", "@9"},
	{"kf0", "k0"},
	{"kf1", "k1"},
	{"kf10", "k;"},
	{"kf11", "F1"},
	{"kf12", "F2"},
	{"kf13", "F3"},
	{"kf14", "F4"},
	{"kf15", "F5"},
	{"kf16", "F6"},
	{"kf17", "F7"},
	{"kf18", "F8"},
	{"kf19", "F9"},
	{"kf2", "k2"},
	{"kf20", "FA"},
	{"kf21", "FB"},
	{"kf22", "FC"},
	{"kf23", "FD"},
	{"kf24", "FE"},
	{"kf25", "FF"},
	{"kf26", "FG"},
	{"kf27", "FH"},
	{"kf28", "FI"},
	{"kf29", "FJ"},
	{"kf3", "k3"},
	{"kf30", "FK"},
	{"kf31", "FL"},
	{"kf32", "FM"},
	{"kf33", "FN"},
	{"kf34", "FO"},
	{"kf35", "FP"},
	{"kf36", "FQ"},
	{"kf37", "FR"},
	{"kf38", "FS"},
	{"kf39", "FT"},
	{"kf4", "k4"},
	{"kf40", "FU"},
	{"kf41", "FV"},
	{"kf42", "FW"},
	{"kf43", "FX"},
	{"kf44", "FY"},
	{"kf45", "FZ"},
	{"kf46", "Fa"},
	{"kf47", "Fb"},
	{"kf48", "Fc"},
	{"kf49", "Fd"},
	{"kf5", "k5"},
	{"kf50", "Fe"},
	{"kf51", "Ff"},
	{"kf52", "Fg"},
	{"kf53", "Fh"},
	{"kf54", "Fi"},
	{"kf55", "Fj"},
	{"kf56", "Fk"},
	{"kf57", "Fl"},
	{"kf58", "Fm"},
	{"kf59", "Fn"},
	{"kf6", "k6"},
	{"kf60", "Fo"},
	{"kf61", "Fp"},
	{"kf62", "Fq"},
	{"kf63", "Fr"},
	{"kf7", "k7"},
	{"kf8", "k8"},
	{"kf9", "k9"},
	{"kfnd", "@0"},
	{"khlp", "%1"},
	{"khome", "kh"},
	{"khts", "kT"},
	{"kich1", "kI"},
	{"kil1", "kA"},
	{"kind", "kF"},
	{"kll", "kH"},
	{"km", "km"},
	{"kmov", "%4"},
	{"kmrk", "%2"},
	{"kmsg", "%3"},
	{"knp", "kN"},
	{"knxt", "%5"},
	{"kopn", "%6"},
	{"kopt", "%7"},
	{"kpp", "kP"},
	{"kprt", "%9"},
	{"kprv", "%8"},
	{"krdo", "%0"},
	{"kref", "&1"},
	{"kres", "&5"},
	{"krfr", "&2"},
	{"kri", "kR"},
	{"krmir", "kM"},
	{"krpl", "&3"},
	{"krst", "&4"},
	{"ksav", "&6"},
	{"kslt", "*6"},
	{"kspd", "&7"},
	{"ktbc", "ka"},
	{"kund", "&8"},
	{"lf0", "l0"},
	{"lf1", "l1"},
	{"lf10", "la"},
	{"lf2", "l2"},
	{"lf3", "l3"},
	{"lf4", "l4"},
	{"lf5", "l5"},
	{"lf6", "l6"},
	{"lf7", "l7"},
	{"lf8", "l8"},
	{"lf9", "l9"},
	{"lh", "lh"},
	{"lines", "li"},
	{"ll", "ll"},
	{"lm", "lm"},
	{"lw", "lw"},
	{"mc0", "ps"},
	{"mc4", "pf"},
	{"mc5", "po"},
	{"mc5i", "5i"},
	{"mc5p", "pO"},
	{"mgc", "MC"},
	{"mir", "mi"},
	{"mrcup", "CM"},
	{"msgr", "ms"},
	{"nel", "nw"},
	{"nlab", "Nl"},
	{"npc", "NP"},
	{"nrrmc", "NR"},
	{"nxon", "nx"},
	{"os", "os"},
	{"pad", "pc"},
	{"pb", "pb"},
	{"pfkey", "pk"},
	{"pfloc", "pl"},
	{"pfx", "px"},
	{"pln", "pn"},
	{"prot", "mp"},
	{"rc", "rc"},
	{"rep", "rp"},
	{"rev", "mr"},
	{"rf", "rf"},
	{"rfi", "RF"},
	{"ri", "sr"},
	{"rin", "SR"},
	{"rmacs", "ae"},
	{"rmam", "RA"},
	{"rmcup", "te"},
	{"rmdc", "ed"},
	{"rmir", "ei"},
	{"rmkx", "ke"},
	{"rmln", "LF"},
	{"rmm", "mo"},
	{"rmp", "rP"},
	{"rmso", "se"},
	{"rmul", "ue"},
	{"rmxon", "RX"},
	{"rs1", "r1"},
	{"rs2", "r2"},
	{"rs3", "r3"},
	{"sc", "sc"},
	{"sgr", "sa"},
	{"sgr0", "me"},
	{"smacs", "as"},
	{"smam", "SA"},
	{"smcup", "ti"},
	{"smdc", "dm"},
	{"smgl", "ML"},
	{"smgr", "MR"},
	{"smir", "im"},
	{"smkx", "ks"},
	{"smln", "LO"},
	{"smm", "mm"},
	{"smso", "so"},
	{"smul", "us"},
	{"smxon", "SX"},
	{"tbc", "ct"},
	{"tsl", "ts"},
	{"uc", "uc"},
	{"ul", "ul"},
	{"vpa", "cv"},
	{"vt", "vt"},
	{"wind", "wi"},
	{"wsl", "ws"},
	{"xenl", "xn"},
	{"xhp", "xs"},
	{"xmc", "sg"},
	{"xoffc", "XF"},
	{"xon", "xo"},
	{"xonc", "XN"},
	{"xsb", "xb"},
	{"xt", "xt"}
};

int errno;
unsigned short errsup = 0;
